var toml = require('toml');
var moment = require('moment');
var path = require('path');
var jsesc = require('jsesc')

var readPageWorker = function(content, obj) {
  if(content === undefined) throw new Error('content is undefined');
  var head = content.substring(0,4)
  if(head !== '+++\n')
    throw new Error('Failed to parse file '+obj.filename+':\n'+
                    'Wrong header (expected "+++\\n" got "'+jsesc(head)+'")')

  content = content.substring(4);
  var fmEnd = content.indexOf('+++\n');
  if(fmEnd < 0) {
    console.log(jsesc(content));
    throw new Error('Cannot find terminating +++\n in file '+obj.filename);
  }
  obj.content = content.substring(fmEnd+4);
  try {
    obj.metadata = toml.parse(content.substring(0,fmEnd-1)+'\n');
  } catch(e) {
    console.log(obj.filename+': Failed to parse metadata');
    throw e;
  }
  if(obj.metadata.date && obj.metadata.date.creation) obj.metadata.date.creation = moment(obj.metadata.date.creation);
  return obj;
}

module.exports = function(obj) {
  return new Promise(function(resolve, reject) {
    var pages = [];
    obj.pages.forEach(function(page) {
      pages.push(readPageWorker(page.content, page));
    })
    obj.pages = pages;
    resolve(obj);
  });
}
